@@ -28,8 +28,13 @@ __all__ = (
     "CsvOptionsTypeDef",
     "CsvOutputOptionsTypeDef",
     "DataCatalogInputDefinitionTypeDef",
+    "DatabaseInputDefinitionTypeDef",
+    "DatasetParameterTypeDef",
     "DatasetTypeDef",
+    "DatetimeOptionsTypeDef",
     "ExcelOptionsTypeDef",
+    "FilesLimitTypeDef",
+    "FilterExpressionTypeDef",
     "FormatOptionsTypeDef",
     "InputTypeDef",
     "JobRunTypeDef",
@@ -38,6 +43,7 @@ __all__ = (
     "JsonOptionsTypeDef",
     "OutputFormatOptionsTypeDef",
     "OutputTypeDef",
+    "PathOptionsTypeDef",
     "ProjectTypeDef",
     "RecipeActionTypeDef",
     "RecipeReferenceTypeDef",
@@ -125,6 +131,39 @@ class DataCatalogInputDefinitionTypeDef(
     pass
 
 
+_RequiredDatabaseInputDefinitionTypeDef = TypedDict(
+    "_RequiredDatabaseInputDefinitionTypeDef", {"GlueConnectionName": str, "DatabaseTableName": str}
+)
+_OptionalDatabaseInputDefinitionTypeDef = TypedDict(
+    "_OptionalDatabaseInputDefinitionTypeDef", {"TempDirectory": "S3LocationTypeDef"}, total=False
+)
+
+
+class DatabaseInputDefinitionTypeDef(
+    _RequiredDatabaseInputDefinitionTypeDef, _OptionalDatabaseInputDefinitionTypeDef
+):
+    pass
+
+
+_RequiredDatasetParameterTypeDef = TypedDict(
+    "_RequiredDatasetParameterTypeDef",
+    {"Name": str, "Type": Literal["Datetime", "Number", "String"]},
+)
+_OptionalDatasetParameterTypeDef = TypedDict(
+    "_OptionalDatasetParameterTypeDef",
+    {
+        "DatetimeOptions": "DatetimeOptionsTypeDef",
+        "CreateColumn": bool,
+        "Filter": "FilterExpressionTypeDef",
+    },
+    total=False,
+)
+
+
+class DatasetParameterTypeDef(_RequiredDatasetParameterTypeDef, _OptionalDatasetParameterTypeDef):
+    pass
+
+
 _RequiredDatasetTypeDef = TypedDict(
     "_RequiredDatasetTypeDef", {"Name": str, "Input": "InputTypeDef"}
 )
@@ -138,7 +177,8 @@ _OptionalDatasetTypeDef = TypedDict(
         "FormatOptions": "FormatOptionsTypeDef",
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
-        "Source": Literal["S3", "DATA-CATALOG"],
+        "Source": Literal["S3", "DATA-CATALOG", "DATABASE"],
+        "PathOptions": "PathOptionsTypeDef",
         "Tags": Dict[str, str],
         "ResourceArn": str,
     },
@@ -150,12 +190,38 @@ class DatasetTypeDef(_RequiredDatasetTypeDef, _OptionalDatasetTypeDef):
     pass
 
 
+_RequiredDatetimeOptionsTypeDef = TypedDict("_RequiredDatetimeOptionsTypeDef", {"Format": str})
+_OptionalDatetimeOptionsTypeDef = TypedDict(
+    "_OptionalDatetimeOptionsTypeDef", {"TimezoneOffset": str, "LocaleCode": str}, total=False
+)
+
+
+class DatetimeOptionsTypeDef(_RequiredDatetimeOptionsTypeDef, _OptionalDatetimeOptionsTypeDef):
+    pass
+
+
 ExcelOptionsTypeDef = TypedDict(
     "ExcelOptionsTypeDef",
     {"SheetNames": List[str], "SheetIndexes": List[int], "HeaderRow": bool},
     total=False,
 )
 
+_RequiredFilesLimitTypeDef = TypedDict("_RequiredFilesLimitTypeDef", {"MaxFiles": int})
+_OptionalFilesLimitTypeDef = TypedDict(
+    "_OptionalFilesLimitTypeDef",
+    {"OrderedBy": Literal["LAST_MODIFIED_DATE"], "Order": Literal["DESCENDING", "ASCENDING"]},
+    total=False,
+)
+
+
+class FilesLimitTypeDef(_RequiredFilesLimitTypeDef, _OptionalFilesLimitTypeDef):
+    pass
+
+
+FilterExpressionTypeDef = TypedDict(
+    "FilterExpressionTypeDef", {"Expression": str, "ValuesMap": Dict[str, str]}
+)
+
 FormatOptionsTypeDef = TypedDict(
     "FormatOptionsTypeDef",
     {"Json": "JsonOptionsTypeDef", "Excel": "ExcelOptionsTypeDef", "Csv": "CsvOptionsTypeDef"},
@@ -167,6 +233,7 @@ InputTypeDef = TypedDict(
     {
         "S3InputDefinition": "S3LocationTypeDef",
         "DataCatalogInputDefinition": "DataCatalogInputDefinitionTypeDef",
+        "DatabaseInputDefinition": "DatabaseInputDefinitionTypeDef",
     },
     total=False,
 )
@@ -259,6 +326,16 @@ class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
     pass
 
 
+PathOptionsTypeDef = TypedDict(
+    "PathOptionsTypeDef",
+    {
+        "LastModifiedDateCondition": "FilterExpressionTypeDef",
+        "FilesLimit": "FilesLimitTypeDef",
+        "Parameters": Dict[str, "DatasetParameterTypeDef"],
+    },
+    total=False,
+)
+
 _RequiredProjectTypeDef = TypedDict("_RequiredProjectTypeDef", {"Name": str, "RecipeName": str})
 _OptionalProjectTypeDef = TypedDict(
     "_OptionalProjectTypeDef",
@@ -453,7 +530,8 @@ _OptionalDescribeDatasetResponseTypeDef = TypedDict(
         "FormatOptions": "FormatOptionsTypeDef",
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
-        "Source": Literal["S3", "DATA-CATALOG"],
+        "Source": Literal["S3", "DATA-CATALOG", "DATABASE"],
+        "PathOptions": "PathOptionsTypeDef",
         "Tags": Dict[str, str],
         "ResourceArn": str,
     },
